@@ -1,3 +1,4 @@
+#coding: utf-8
 from sqlee.utils.django import models
 from django.forms.models import model_to_dict
 from threading import Thread
@@ -9,15 +10,10 @@ import sys
 import json
 import requests
 
-if 'DJANGO_SETTINGS_MODULE' in os.environ:
-    settings = __import__(os.environ['DJANGO_SETTINGS_MODULE']).settings
+if __name__ == "__main__":
+    from verify import verify_django
 else:
-    raise ImportError("Django工程未被执行，请在Django工程中导入Sqlee的Django组件.")
-try:
-    if not settings.ENABLE_SQLEE or settings.SQLEE_NAME.replace(" ", "") == "":
-        raise ImportError('Sqlee未在Django被正确配置.')
-except Exception as exc:
-    raise ImportError('Sqlee未在Django被正确配置.') from exc
+    from .verify import verify_django
 
 def init():
     url = json.loads(requests.get("https://gitee.com/api/v5/repos/{user}/{name}?access_token={token}".format(
@@ -111,4 +107,6 @@ def sync():
     return datas
 
 def execute_from_command_line(argv):
-    return eval(argv[1])()
\ No newline at end of file
+    return eval(argv[1])()
+
+settings = verify_django()
